@@ -1,16 +1,14 @@
-from __future__ import absolute_import
 __author__ = "Jon Reid"
 __copyright__ = "Copyright 2011 hamcrest.org"
 __license__ = "BSD, see License.txt"
 
-from hamcrest.core.base_matcher import BaseMatcher, Matcher
-from hamcrest.core.helpers.wrap_matcher import wrap_matcher, is_matchable_type
-from .isequal import equal_to
+from hamcrest.core.base_matcher import BaseMatcher
+from hamcrest.core.helpers.wrap_matcher import is_matchable_type, wrap_matcher
+
 from .isinstanceof import instance_of
 
 
 class IsNot(BaseMatcher):
-
     def __init__(self, matcher):
         self.matcher = matcher
 
@@ -18,7 +16,7 @@ class IsNot(BaseMatcher):
         return not self.matcher.matches(item)
 
     def describe_to(self, description):
-        description.append_text('not ').append_description_of(self.matcher)
+        description.append_text("not ").append_description_of(self.matcher)
 
 
 def wrap_value_or_type(x):
@@ -46,6 +44,7 @@ def is_not(match):
     """
     return IsNot(wrap_value_or_type(match))
 
+
 def not_(match):
     """Alias of :py:func:`is_not` for better readability of negations.
 
