@@ -4,24 +4,21 @@ __license__ = "BSD, see License.txt"
 
 from hamcrest.core.base_matcher import BaseMatcher
 
-import six
 
 class IsEqualIgnoringCase(BaseMatcher):
-
     def __init__(self, string):
-        if not isinstance(string, six.string_types):
-            raise TypeError('IsEqualIgnoringCase requires string')
+        if not isinstance(string, str):
+            raise TypeError("IsEqualIgnoringCase requires string")
         self.original_string = string
         self.lowered_string = string.lower()
 
     def _matches(self, item):
-        if not isinstance(item, six.string_types):
+        if not isinstance(item, str):
             return False
         return self.lowered_string == item.lower()
 
     def describe_to(self, description):
-        description.append_description_of(self.original_string)    \
-                   .append_text(' ignoring case')
+        description.append_description_of(self.original_string).append_text(" ignoring case")
 
 
 def equal_to_ignoring_case(string):
