@@ -2,22 +2,21 @@ __author__ = "Jon Reid"
 __copyright__ = "Copyright 2011 hamcrest.org"
 __license__ = "BSD, see License.txt"
 
-from hamcrest.library.text.substringmatcher import SubstringMatcher
 from hamcrest.core.helpers.hasmethod import hasmethod
+from hamcrest.library.text.substringmatcher import SubstringMatcher
 
 
 class StringStartsWith(SubstringMatcher):
-
     def __init__(self, substring):
         super(StringStartsWith, self).__init__(substring)
 
     def _matches(self, item):
-        if not hasmethod(item, 'startswith'):
+        if not hasmethod(item, "startswith"):
             return False
         return item.startswith(self.substring)
 
     def relationship(self):
-        return 'starting with'
+        return "starting with"
 
 
 def starts_with(substring):
